/**
 * Das Interface Figure definiert die gemeinsame
 * Schnittstelle fr verschiedene geometrische Figuren.
 * @author fischer
 * @version 1.0
 */
public interface Figure71 {
    /**
     * Berechnet die Flche der geometrischen Figur
     * @return Die Flche der Figur
     */
    public double area();

    /**
     * Berechnet dem Unfang der Figur, d.h. die Lnge der "Auenkanten".
     * @return der Umfang der Figur.
     */
    public double circumference();

    /**
     * Berechnet, ob die Figure den Punkt mit den angegbenen Koordinaten
     * berdeckt.
     * @param x Die x-Koordinate des zu berprfenden Punktes
     * @param y Die y-Koordinate des zu berprfenden Punktes
     * @return true wenn die Figur den Punkt berdeckt,
     *         false sonst.
     */
    public boolean overlaps(double x, double y);

    /**
     * Liefert einen, die Figur beschreibenden String, mit dem Namen der Figur
     * und den wichtigsten Attributen.
     * @return Eine textuelle Beschreibung der Figur.
     */
    public String toString();

    /**
     * Setzt die Farbe der Figure mit den angegebenen RGB Werten.
     * @param red Rot-Wert der Farbe (Wertebereich: 0 bis 255)
     * @param green Grn-Wert der Farbe (Wertebereich: 0 bis 255)
     * @param blue Blau-Wert der Farbe (Wertebereich: 0 bis 255)
     */
    public void setColor(int red, int green, int blue);

    /**
     * Liefert den Rot-Wert der Farbe der Figur
     * @return den Rot-Wert der Farbe (0-255)
     */
    public int getColorRed();

    /**
     * Liefert den Grn-Wert der Farbe der Figur
     * @return den Grn-Wert der Farbe (0-255)
     */
    public int getColorGreen();

    /**
     * Liefert den Blau-Wert der Farbe der Figur
     * @return der Frn-Wert der Farbe (0-255)
     */
    public int getColorBlue();
}
